aboutsummaryrefslogtreecommitdiffstats
path: root/models/actions/run.go
diff options
context:
space:
mode:
authorZettat123 <zettat123@gmail.com>2023-06-26 14:33:18 +0800
committerGitHub <noreply@github.com>2023-06-26 14:33:18 +0800
commit48e5a74f215d78813a816c57fc5a85a909a003d5 (patch)
treef0be66ae5111de6dc17ea7975e6a592a9b235f3c /models/actions/run.go
parente409e14bdfb56767c9048076f4e818757aab73b9 (diff)
downloadgitea-48e5a74f215d78813a816c57fc5a85a909a003d5.tar.gz
gitea-48e5a74f215d78813a816c57fc5a85a909a003d5.zip
Support `pull_request_target` event (#25229)
Fix #25088 This PR adds the support for [`pull_request_target`](https://docs.github.com/en/actions/using-workflows/events-that-trigger-workflows#pull_request_target) workflow trigger. `pull_request_target` is similar to `pull_request`, but the workflow triggered by the `pull_request_target` event runs in the context of the base branch of the pull request rather than the head branch. Since the workflow from the base is considered trusted, it can access the secrets and doesn't need approvals to run.
Diffstat (limited to 'models/actions/run.go')
-rw-r--r--models/actions/run.go13
1 files changed, 7 insertions, 6 deletions
diff --git a/models/actions/run.go b/models/actions/run.go
index 0654809900..7b62ff884f 100644
--- a/models/actions/run.go
+++ b/models/actions/run.go
@@ -36,12 +36,13 @@ type ActionRun struct {
TriggerUser *user_model.User `xorm:"-"`
Ref string
CommitSHA string
- IsForkPullRequest bool // If this is triggered by a PR from a forked repository or an untrusted user, we need to check if it is approved and limit permissions when running the workflow.
- NeedApproval bool // may need approval if it's a fork pull request
- ApprovedBy int64 `xorm:"index"` // who approved
- Event webhook_module.HookEventType
- EventPayload string `xorm:"LONGTEXT"`
- Status Status `xorm:"index"`
+ IsForkPullRequest bool // If this is triggered by a PR from a forked repository or an untrusted user, we need to check if it is approved and limit permissions when running the workflow.
+ NeedApproval bool // may need approval if it's a fork pull request
+ ApprovedBy int64 `xorm:"index"` // who approved
+ Event webhook_module.HookEventType // the webhook event that causes the workflow to run
+ EventPayload string `xorm:"LONGTEXT"`
+ TriggerEvent string // the trigger event defined in the `on` configuration of the triggered workflow
+ Status Status `xorm:"index"`
Started timeutil.TimeStamp
Stopped timeutil.TimeStamp
Created timeutil.TimeStamp `xorm:"created"`